<?php
/*
* Plugin Name: Hangman
* Description: This plugin allows you to play the Hangman game. To make the Hangman appear, you need to insert the shortcode [hangman] in the page you wish.
* Version: 1.0
* Author: Marc Oliveras
* Author URI: http://oligalma.com
* License: GPLv3
*/

// Exit if accessed directly
if (!defined('ABSPATH'))
	exit;

!is_admin() && add_shortcode('hangman', 'hangman_creation');

function hangman_creation(){
	if(isset($_POST['action']))
		$action = sanitize_text_field($_POST['action']);
	else
		$action = 0;

	switch($action)
	{
		case 0: // Title

			$levels = array('0' => 'Easy game: you are allowed 10 misses.',
					'1' => 'Medium game: you are allowed 5 misses.',
					'2' => 'Hard game: you are allowed 3 misses.');
			
			require 'title.php';
				
			break;
			
		case 1: // Start
			$lines = file(plugins_url('/dictionary.txt', __FILE__));      
			$word = $lines[rand(0, count($lines) - 1)];
			$word = substr($word, 0, strlen($word) - 1);        

			$foundLetters = '';
			
			$level = 0;
			if(isset($_POST['level']))
				$level = sanitize_text_field($_POST['level']);
						
			switch($level)
			{
				case 0: // Easy
					$lives = 10;
					break;
				case 1: // Medium
					$lives = 5;
					break;
				case 2: // Hard
					$lives = 3;
					break;                
			}
						
			$image = 0;
			
			$blankWord =  '';
			for($i = 0; $i < strlen($word); $i++)
				$blankWord .= (substr($word,$i,1) != ' ' ? '<span class="guessed-letter">_</span>' : ' ');	
			
			$word = trim($word);
			
			require 'start.php';
			
			break;
	}

}

!is_admin() && add_action('init', 'hangman_register_styles');

function hangman_register_styles()
{
    wp_enqueue_style('hangman_style', plugins_url('/css/style.css', __FILE__));
}

add_action('wp_ajax_hangman_ajax', 'hangman_ajax' );
add_action('wp_ajax_nopriv_hangman_ajax', 'hangman_ajax' );

function hangman_ajax()
{
	$lives = sanitize_text_field($_POST['lives']);
	$image = sanitize_text_field($_POST['image']);
	$word = sanitize_text_field(trim($_POST['word']));
	$foundLetters = sanitize_text_field($_POST['foundLetters']);
	$level = sanitize_text_field($_POST['level']);
	$letter = sanitize_text_field(strtolower($_POST['letter']));
	$win = null;

	$response = array();

	if(strpos(strtolower($word), $letter) === false)
	{
		$lives -= 1;
		switch($level)
		{
			case 0:
				$image += 1;
				break;
			case 1:
				$image += 2;
				break;
			case 2:
				if($image == 0)
					$image = 3;
				elseif($image == 3)
					$image = 6;
				else
					$image = 10;
				break;
		}
		
		$response['image_url'] = plugins_url('/images/hangman/' . $image . '.jpg', __FILE__);
		
		if($lives == 0)
		{
			$win = false;
			$response['word'] = 'The word was: <b>' . $word . '</b>';
		}             
	}   
	else
	{
		$foundLetters .= $letter;

		$i = 0;
		$wordLetters = str_split($word);
		$foundLetters2 = str_split($foundLetters);
		foreach($wordLetters as $letter)
		{
			$found = false;
		
			foreach($foundLetters2 as $letter2)
			{
				if(strtolower($letter) == strtolower($letter2))
				{
					$found = true;
					break;
				}
			}
		
			if($found)
				$i++;
		}  
		if($i == strlen($word) - substr_count($word, ' '))
			$win = true;
	}


	$wordLetters = str_split($word);
	$foundLetters2 = str_split($foundLetters);
	$guessedWord = '';

	foreach($wordLetters as $letter)
	{
		$found = false;

		foreach($foundLetters2 as $letter2)
		{
			if(strtolower($letter) == strtolower($letter2))
			{
				$found = true;
				break;
			}
		}
			
		if($found)
			$guessedWord .= $letter;
		elseif($letter != ' ')
			$guessedWord .= '<span class="guessed-letter">_</span>';
		else
			$guessedWord .= ' ';
	}  

	$response['foundLetters'] = $foundLetters;
	$response['image'] = $image;
	$response['win'] = $win;
	$response['lives'] = $lives;
	$response['guessedWord'] = $guessedWord;

	echo wp_send_json($response);
}
